@@ -8,300 +8,300 @@ extern crate test;
 use test::{black_box, Bencher};
 
 use arrayvec::ArrayVec;
-use staticvec::StaticVec;
+use staticvec::{staticvec, StaticVec};
 
 #[bench]
-fn staticvec_push_u32_255(b: &mut Bencher) {
+fn u32_255_staticvec_push(b: &mut Bencher) {
   let mut v = StaticVec::<u32, 255>::new();
   b.iter(|| {
     v.clear();
     for i in 0..255 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn arrayvec_push_u32_255(b: &mut Bencher) {
+fn u32_255_arrayvec_push(b: &mut Bencher) {
   let mut v = ArrayVec::<[u32; 255]>::new();
   b.iter(|| {
     v.clear();
     for i in 0..255 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn staticvec_push_u32_512(b: &mut Bencher) {
+fn u32_512_staticvec_push(b: &mut Bencher) {
   let mut v = StaticVec::<u32, 512>::new();
   b.iter(|| {
     v.clear();
     for i in 0..512 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn arrayvec_push_u32_512(b: &mut Bencher) {
+fn u32_512_arrayvec_push(b: &mut Bencher) {
   let mut v = ArrayVec::<[u32; 512]>::new();
   b.iter(|| {
     v.clear();
     for i in 0..512 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn staticvec_push_u32_1024(b: &mut Bencher) {
+fn u32_1024_staticvec_push(b: &mut Bencher) {
   let mut v = StaticVec::<u32, 1024>::new();
   b.iter(|| {
     v.clear();
     for i in 0..1024 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn arrayvec_push_u32_1024(b: &mut Bencher) {
+fn u32_1024_arrayvec_push(b: &mut Bencher) {
   let mut v = ArrayVec::<[u32; 1024]>::new();
   b.iter(|| {
     v.clear();
     for i in 0..1024 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn staticvec_push_u32_2048(b: &mut Bencher) {
+fn u32_2048_staticvec_push(b: &mut Bencher) {
   let mut v = StaticVec::<u32, 2048>::new();
   b.iter(|| {
     v.clear();
     for i in 0..2048 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn arrayvec_push_u32_2048(b: &mut Bencher) {
+fn u32_2048_arrayvec_push(b: &mut Bencher) {
   let mut v = ArrayVec::<[u32; 2048]>::new();
   b.iter(|| {
     v.clear();
     for i in 0..2048 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn staticvec_push_u32_4096(b: &mut Bencher) {
+fn u32_4096_staticvec_push(b: &mut Bencher) {
   let mut v = StaticVec::<u32, 4096>::new();
   b.iter(|| {
     v.clear();
     for i in 0..4096 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn arrayvec_push_u32_4096(b: &mut Bencher) {
+fn u32_4096_arrayvec_push(b: &mut Bencher) {
   let mut v = ArrayVec::<[u32; 4096]>::new();
   b.iter(|| {
     v.clear();
     for i in 0..4096 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn staticvec_push_u32_8192(b: &mut Bencher) {
+fn u32_8192_staticvec_push(b: &mut Bencher) {
   let mut v = StaticVec::<u32, 8192>::new();
   b.iter(|| {
     v.clear();
     for i in 0..8192 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn arrayvec_push_u32_8192(b: &mut Bencher) {
+fn u32_8192_arrayvec_push(b: &mut Bencher) {
   let mut v = ArrayVec::<[u32; 8192]>::new();
   b.iter(|| {
     v.clear();
     for i in 0..8192 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn staticvec_push_u64_255(b: &mut Bencher) {
+fn u64_255_staticvec_push(b: &mut Bencher) {
   let mut v = StaticVec::<u64, 255>::new();
   b.iter(|| {
     v.clear();
     for i in 0..255 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn arrayvec_push_u64_255(b: &mut Bencher) {
+fn u64_255_arrayvec_push(b: &mut Bencher) {
   let mut v = ArrayVec::<[u64; 255]>::new();
   b.iter(|| {
     v.clear();
     for i in 0..255 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn staticvec_push_u64_512(b: &mut Bencher) {
+fn u64_512_staticvec_push(b: &mut Bencher) {
   let mut v = StaticVec::<u64, 512>::new();
   b.iter(|| {
     v.clear();
     for i in 0..512 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn arrayvec_push_u64_512(b: &mut Bencher) {
+fn u64_512_arrayvec_push(b: &mut Bencher) {
   let mut v = ArrayVec::<[u64; 512]>::new();
   b.iter(|| {
     v.clear();
     for i in 0..512 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn staticvec_push_u64_1024(b: &mut Bencher) {
+fn u64_1024_staticvec_push(b: &mut Bencher) {
   let mut v = StaticVec::<u64, 1024>::new();
   b.iter(|| {
     v.clear();
     for i in 0..1024 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn arrayvec_push_u64_1024(b: &mut Bencher) {
+fn u64_1024_arrayvec_push(b: &mut Bencher) {
   let mut v = ArrayVec::<[u64; 1024]>::new();
   b.iter(|| {
     v.clear();
     for i in 0..1024 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn staticvec_push_u64_2048(b: &mut Bencher) {
+fn u64_2048_staticvec_push(b: &mut Bencher) {
   let mut v = StaticVec::<u64, 2048>::new();
   b.iter(|| {
     v.clear();
     for i in 0..2048 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn arrayvec_push_u64_2048(b: &mut Bencher) {
+fn u64_2048_arrayvec_push(b: &mut Bencher) {
   let mut v = ArrayVec::<[u64; 2048]>::new();
   b.iter(|| {
     v.clear();
     for i in 0..2048 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn staticvec_push_u64_4096(b: &mut Bencher) {
+fn u64_4096_staticvec_push(b: &mut Bencher) {
   let mut v = StaticVec::<u64, 4096>::new();
   b.iter(|| {
     v.clear();
     for i in 0..4096 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn arrayvec_push_u64_4096(b: &mut Bencher) {
+fn u64_4096_arrayvec_push(b: &mut Bencher) {
   let mut v = ArrayVec::<[u64; 4096]>::new();
   b.iter(|| {
     v.clear();
     for i in 0..4096 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn staticvec_push_u64_8192(b: &mut Bencher) {
+fn u64_8192_staticvec_push(b: &mut Bencher) {
   let mut v = StaticVec::<u64, 8192>::new();
   b.iter(|| {
     v.clear();
     for i in 0..8192 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn arrayvec_push_u64_8192(b: &mut Bencher) {
+fn u64_8192_arrayvec_push(b: &mut Bencher) {
   let mut v = ArrayVec::<[u64; 8192]>::new();
   b.iter(|| {
     v.clear();
     for i in 0..8192 {
-      black_box(v.push(i));
+      v.push(black_box(i));
     }
   });
   b.bytes = v.capacity() as u64;
 }
 
 #[bench]
-fn staticvec_pop_u32_255(b: &mut Bencher) {
+fn u32_255_staticvec_pop(b: &mut Bencher) {
   b.iter(|| {
-    let mut v = StaticVec::<u32, 255>::from([128; 255]);
+    let mut v = staticvec![128u32; 255];
     for _ in 0..255 {
       black_box(v.pop().unwrap());
     }
@@ -310,7 +310,7 @@ fn staticvec_pop_u32_255(b: &mut Bencher) {
 }
 
 #[bench]
-fn arrayvec_pop_u32_255(b: &mut Bencher) {
+fn u32_255_arrayvec_pop(b: &mut Bencher) {
   b.iter(|| {
     let mut v = ArrayVec::<[u32; 255]>::from([128; 255]);
     for _ in 0..255 {
@@ -321,9 +321,9 @@ fn arrayvec_pop_u32_255(b: &mut Bencher) {
 }
 
 #[bench]
-fn staticvec_pop_u32_512(b: &mut Bencher) {
+fn u32_512_staticvec_pop(b: &mut Bencher) {
   b.iter(|| {
-    let mut v = StaticVec::<u32, 512>::from([128; 512]);
+    let mut v = staticvec![128u32; 512];
     for _ in 0..512 {
       black_box(v.pop().unwrap());
     }
@@ -332,7 +332,7 @@ fn staticvec_pop_u32_512(b: &mut Bencher) {
 }
 
 #[bench]
-fn arrayvec_pop_u32_512(b: &mut Bencher) {
+fn u32_512_arrayvec_pop(b: &mut Bencher) {
   b.iter(|| {
     let mut v = ArrayVec::<[u32; 512]>::from([128; 512]);
     for _ in 0..512 {
@@ -343,9 +343,9 @@ fn arrayvec_pop_u32_512(b: &mut Bencher) {
 }
 
 #[bench]
-fn staticvec_pop_u32_1024(b: &mut Bencher) {
+fn u32_1024_staticvec_pop(b: &mut Bencher) {
   b.iter(|| {
-    let mut v = StaticVec::<u32, 1024>::from([128; 1024]);
+    let mut v = staticvec![128u32; 1024];
     for _ in 0..1024 {
       black_box(v.pop().unwrap());
     }
@@ -354,7 +354,7 @@ fn staticvec_pop_u32_1024(b: &mut Bencher) {
 }
 
 #[bench]
-fn arrayvec_pop_u32_1024(b: &mut Bencher) {
+fn u32_1024_arrayvec_pop(b: &mut Bencher) {
   b.iter(|| {
     let mut v = ArrayVec::<[u32; 1024]>::from([128; 1024]);
     for _ in 0..1024 {
@@ -365,9 +365,9 @@ fn arrayvec_pop_u32_1024(b: &mut Bencher) {
 }
 
 #[bench]
-fn staticvec_pop_u32_2048(b: &mut Bencher) {
+fn u32_2048_staticvec_pop(b: &mut Bencher) {
   b.iter(|| {
-    let mut v = StaticVec::<u32, 2048>::from([128; 2048]);
+    let mut v = staticvec![128u32; 2048];
     for _ in 0..2048 {
       black_box(v.pop().unwrap());
     }
@@ -376,7 +376,7 @@ fn staticvec_pop_u32_2048(b: &mut Bencher) {
 }
 
 #[bench]
-fn arrayvec_pop_u32_2048(b: &mut Bencher) {
+fn u32_2048_arrayvec_pop(b: &mut Bencher) {
   b.iter(|| {
     let mut v = ArrayVec::<[u32; 2048]>::from([128; 2048]);
     for _ in 0..2048 {
@@ -387,9 +387,9 @@ fn arrayvec_pop_u32_2048(b: &mut Bencher) {
 }
 
 #[bench]
-fn staticvec_pop_u32_4096(b: &mut Bencher) {
+fn u32_4096_staticvec_pop(b: &mut Bencher) {
   b.iter(|| {
-    let mut v = StaticVec::<u32, 4096>::from([128; 4096]);
+    let mut v = staticvec![128u32; 4096];
     for _ in 0..4096 {
       black_box(v.pop().unwrap());
     }
@@ -398,7 +398,7 @@ fn staticvec_pop_u32_4096(b: &mut Bencher) {
 }
 
 #[bench]
-fn arrayvec_pop_u32_4096(b: &mut Bencher) {
+fn u32_4096_arrayvec_pop(b: &mut Bencher) {
   b.iter(|| {
     let mut v = ArrayVec::<[u32; 4096]>::from([128; 4096]);
     for _ in 0..4096 {
@@ -409,9 +409,9 @@ fn arrayvec_pop_u32_4096(b: &mut Bencher) {
 }
 
 #[bench]
-fn staticvec_pop_u32_8192(b: &mut Bencher) {
+fn u32_8192_staticvec_pop(b: &mut Bencher) {
   b.iter(|| {
-    let mut v = StaticVec::<u32, 8192>::from([128; 8192]);
+    let mut v = staticvec![128u32; 8192];
     for _ in 0..8192 {
       black_box(v.pop().unwrap());
     }
@@ -420,7 +420,7 @@ fn staticvec_pop_u32_8192(b: &mut Bencher) {
 }
 
 #[bench]
-fn arrayvec_pop_u32_8192(b: &mut Bencher) {
+fn u32_8192_arrayvec_pop(b: &mut Bencher) {
   b.iter(|| {
     let mut v = ArrayVec::<[u32; 8192]>::from([128; 8192]);
     for _ in 0..8192 {
@@ -431,9 +431,9 @@ fn arrayvec_pop_u32_8192(b: &mut Bencher) {
 }
 
 #[bench]
-fn staticvec_pop_u64_255(b: &mut Bencher) {
+fn u64_255_staticvec_pop(b: &mut Bencher) {
   b.iter(|| {
-    let mut v = StaticVec::<u64, 255>::from([128; 255]);
+    let mut v = staticvec![128u64; 255];
     for _ in 0..255 {
       black_box(v.pop().unwrap());
     }
@@ -442,7 +442,7 @@ fn staticvec_pop_u64_255(b: &mut Bencher) {
 }
 
 #[bench]
-fn arrayvec_pop_u64_255(b: &mut Bencher) {
+fn u64_255_arrayvec_pop(b: &mut Bencher) {
   b.iter(|| {
     let mut v = ArrayVec::<[u64; 255]>::from([128; 255]);
     for _ in 0..255 {
@@ -453,9 +453,9 @@ fn arrayvec_pop_u64_255(b: &mut Bencher) {
 }
 
 #[bench]
-fn staticvec_pop_u64_512(b: &mut Bencher) {
+fn u64_512_staticvec_pop(b: &mut Bencher) {
   b.iter(|| {
-    let mut v = StaticVec::<u64, 512>::from([128; 512]);
+    let mut v = staticvec![128u64; 512];
     for _ in 0..512 {
       black_box(v.pop().unwrap());
     }
@@ -464,7 +464,7 @@ fn staticvec_pop_u64_512(b: &mut Bencher) {
 }
 
 #[bench]
-fn arrayvec_pop_u64_512(b: &mut Bencher) {
+fn u64_512_arrayvec_pop(b: &mut Bencher) {
   b.iter(|| {
     let mut v = ArrayVec::<[u64; 512]>::from([128; 512]);
     for _ in 0..512 {
@@ -475,9 +475,9 @@ fn arrayvec_pop_u64_512(b: &mut Bencher) {
 }
 
 #[bench]
-fn staticvec_pop_u64_1024(b: &mut Bencher) {
+fn u64_1024_staticvec_pop(b: &mut Bencher) {
   b.iter(|| {
-    let mut v = StaticVec::<u64, 1024>::from([128; 1024]);
+    let mut v = staticvec![128u64; 1024];
     for _ in 0..1024 {
       black_box(v.pop().unwrap());
     }
@@ -486,7 +486,7 @@ fn staticvec_pop_u64_1024(b: &mut Bencher) {
 }
 
 #[bench]
-fn arrayvec_pop_u64_1024(b: &mut Bencher) {
+fn u64_1024_arrayvec_pop(b: &mut Bencher) {
   b.iter(|| {
     let mut v = ArrayVec::<[u64; 1024]>::from([128; 1024]);
     for _ in 0..1024 {
@@ -497,9 +497,9 @@ fn arrayvec_pop_u64_1024(b: &mut Bencher) {
 }
 
 #[bench]
-fn staticvec_pop_u64_2048(b: &mut Bencher) {
+fn u64_2048_staticvec_pop(b: &mut Bencher) {
   b.iter(|| {
-    let mut v = StaticVec::<u64, 2048>::from([128; 2048]);
+    let mut v = staticvec![128u64; 2048];
     for _ in 0..2048 {
       black_box(v.pop().unwrap());
     }
@@ -508,7 +508,7 @@ fn staticvec_pop_u64_2048(b: &mut Bencher) {
 }
 
 #[bench]
-fn arrayvec_pop_u64_2048(b: &mut Bencher) {
+fn u64_2048_arrayvec_pop(b: &mut Bencher) {
   b.iter(|| {
     let mut v = ArrayVec::<[u64; 2048]>::from([128; 2048]);
     for _ in 0..2048 {
@@ -519,9 +519,9 @@ fn arrayvec_pop_u64_2048(b: &mut Bencher) {
 }
 
 #[bench]
-fn staticvec_pop_u64_4096(b: &mut Bencher) {
+fn u64_4096_staticvec_pop(b: &mut Bencher) {
   b.iter(|| {
-    let mut v = StaticVec::<u64, 4096>::from([128; 4096]);
+    let mut v = staticvec![128u64; 4096];
     for _ in 0..4096 {
       black_box(v.pop().unwrap());
     }
@@ -530,7 +530,7 @@ fn staticvec_pop_u64_4096(b: &mut Bencher) {
 }
 
 #[bench]
-fn arrayvec_pop_u64_4096(b: &mut Bencher) {
+fn u64_4096_arrayvec_pop(b: &mut Bencher) {
   b.iter(|| {
     let mut v = ArrayVec::<[u64; 4096]>::from([128; 4096]);
     for _ in 0..4096 {
@@ -541,9 +541,9 @@ fn arrayvec_pop_u64_4096(b: &mut Bencher) {
 }
 
 #[bench]
-fn staticvec_pop_u64_8192(b: &mut Bencher) {
+fn u64_8192_staticvec_pop(b: &mut Bencher) {
   b.iter(|| {
-    let mut v = StaticVec::<u64, 8192>::from([128; 8192]);
+    let mut v = staticvec![128u64; 8192];
     for _ in 0..8192 {
       black_box(v.pop().unwrap());
     }
@@ -552,7 +552,7 @@ fn staticvec_pop_u64_8192(b: &mut Bencher) {
 }
 
 #[bench]
-fn arrayvec_pop_u64_8192(b: &mut Bencher) {
+fn u64_8192_arrayvec_pop(b: &mut Bencher) {
   b.iter(|| {
     let mut v = ArrayVec::<[u64; 8192]>::from([128; 8192]);
     for _ in 0..8192 {
