@@ -24,7 +24,6 @@ pub use crate::trait_impls::*;
 use crate::utils::{make_const_slice, make_mut_slice, ptr_mut, reverse_copy};
 use core::cmp::{Ord, PartialEq};
 use core::intrinsics;
-use core::iter::FromIterator;
 use core::marker::PhantomData;
 use core::mem::MaybeUninit;
 use core::ops::{
@@ -217,9 +216,11 @@ impl<T, const N: usize> StaticVec<T, N> {
   /// actually initialized. Failure to do so will almost certainly result in undefined behavior.
   #[inline(always)]
   pub unsafe fn set_len(&mut self, new_len: usize) {
+    // Most of the `unsafe` functions in this crate that are heavily used internally
+    // have debug-build-only assertions where it's useful.
     debug_assert!(
       new_len <= N,
-      "Attempted to unsafely set length to {}; maximum is {}!",
+      "In `StaticVec::set_len`, provided length {} exceeds the maximum capacity of {}!",
       new_len,
       N
     );
@@ -279,7 +280,7 @@ impl<T, const N: usize> StaticVec<T, N> {
   }
 
   /// Returns a constant pointer to the element of the StaticVec at `index` without doing any
-  /// checking to ensure that `index` is within the range `0..length`. The return value of this
+  /// checking to ensure that `index` is within the range `0..self.length`. The return value of this
   /// function is equivalent to what would be returned from `as_ptr().add(index)`.
   ///
   /// # Safety
@@ -288,11 +289,14 @@ impl<T, const N: usize> StaticVec<T, N> {
   /// function returns a pointer to valid data.
   #[inline(always)]
   pub unsafe fn ptr_at_unchecked(&self, index: usize) -> *const T {
+    // This can't have a debug assert because it's used internally in functions where `self.length`
+    // has intentionally been temporarily set to 0, and also in things like the iterator
+    // implementations where `end` is initially *at* `self.length`, not `self.length - 1`.
     self.as_ptr().add(index)
   }
 
   /// Returns a mutable pointer to the element of the StaticVec at `index` without doing any
-  /// checking to ensure that `index` is within the range `0..length`. The return value of this
+  /// checking to ensure that `index` is within the range `0..self.length`. The return value of this
   /// function is equivalent to what would be returned from `as_mut_ptr().add(index)`.
   ///
   /// # Safety
@@ -301,17 +305,20 @@ impl<T, const N: usize> StaticVec<T, N> {
   /// function returns a pointer to valid data.
   #[inline(always)]
   pub unsafe fn mut_ptr_at_unchecked(&mut self, index: usize) -> *mut T {
+    // This can't have a debug assert because it's used internally in functions where `self.length`
+    // has intentionally been temporarily set to 0, and also in things like the iterator
+    // implementations where `end` is initially *at* `self.length`, not `self.length - 1`.
     self.as_mut_ptr().add(index)
   }
 
   /// Returns a constant pointer to the element of the StaticVec at `index` if `index`
-  /// is within the range `0..length`, or panics if it is not. The return value of this function is
-  /// equivalent to what would be returned from `as_ptr().add(index)`.
+  /// is within the range `0..self.length`, or panics if it is not. The return value of this
+  /// function is equivalent to what would be returned from `as_ptr().add(index)`.
   #[inline(always)]
   pub fn ptr_at(&self, index: usize) -> *const T {
     assert!(
       index < self.length,
-      "Provided index {} must be between 0 and {}!",
+      "In `StaticVec::ptr_at`, provided index {} must be within `0..{}`!",
       index,
       self.length
     );
@@ -319,13 +326,13 @@ impl<T, const N: usize> StaticVec<T, N> {
   }
 
   /// Returns a mutable pointer to the element of the StaticVec at `index` if `index`
-  /// is within the range `0..length`, or panics if it is not. The return value of this function is
-  /// equivalent to what would be returned from `as_mut_ptr().add(index)`.
+  /// is within the range `0..self.length`, or panics if it is not. The return value of this
+  /// function is equivalent to what would be returned from `as_mut_ptr().add(index)`.
   #[inline(always)]
   pub fn mut_ptr_at(&mut self, index: usize) -> *mut T {
     assert!(
       index < self.length,
-      "Provided index {} must be between 0 and {}!",
+      "In `StaticVec::mut_ptr_at`, provided index {} must be within `0..{}`!",
       index,
       self.length
     );
@@ -339,7 +346,7 @@ impl<T, const N: usize> StaticVec<T, N> {
   ///
   /// Note that unlike [`slice::get_unchecked`](https://doc.rust-lang.org/nightly/std/primitive.slice.html#method.get_unchecked),
   /// this method only supports accessing individual elements via `usize`; it cannot also produce
-  /// subslices. To unsafely get a subslice without a bounds check, use
+  /// subslices. To get a subslice without a bounds check, use
   /// `self.as_slice().get_unchecked(a..b)`.
   ///
   /// # Safety
@@ -349,7 +356,7 @@ impl<T, const N: usize> StaticVec<T, N> {
   pub unsafe fn get_unchecked(&self, index: usize) -> &T {
     debug_assert!(
       index < self.length,
-      "Attempted to unsafely get at index {} when length is {}!",
+      "In `StaticVec::get_unchecked`, provided index {} must be within `0..{}`!",
       index,
       self.length
     );
@@ -371,7 +378,7 @@ impl<T, const N: usize> StaticVec<T, N> {
   pub unsafe fn get_unchecked_mut(&mut self, index: usize) -> &mut T {
     debug_assert!(
       index < self.length,
-      "Attempted to unsafely get at index {} when length is {}!",
+      "In `StaticVec::get_unchecked_mut`, provided index {} must be within `0..{}`!",
       index,
       self.length
     );
@@ -388,11 +395,11 @@ impl<T, const N: usize> StaticVec<T, N> {
   /// in writing to an out-of-bounds memory region.
   #[inline(always)]
   pub unsafe fn push_unchecked(&mut self, value: T) {
-    let length = self.length;
     debug_assert!(
-      length < N,
-      "Attempted to unsafely push to a full StaticVec!"
+      self.is_not_full(),
+      "`StaticVec::push_unchecked` was called through a StaticVec already at maximum capacity!"
     );
+    let length = self.length;
     self.mut_ptr_at_unchecked(length).write(value);
     self.set_len(length + 1);
   }
@@ -409,7 +416,7 @@ impl<T, const N: usize> StaticVec<T, N> {
   pub unsafe fn pop_unchecked(&mut self) -> T {
     debug_assert!(
       self.is_not_empty(),
-      "Attempted to unsafely pop from an empty StaticVec!"
+      "`StaticVec::pop_unchecked` was called through an empty StaticVec!"
     );
     let new_length = self.length - 1;
     self.set_len(new_length);
@@ -875,14 +882,13 @@ impl<T, const N: usize> StaticVec<T, N> {
   /// Due to needing to call `clone()` through each individual element of `self` and `other`, this
   /// function is less efficient than [`concat`](crate::StaticVec::concat), so
   /// [`concat`](crate::StaticVec::concat) should be preferred whenever possible.
+  #[rustfmt::skip]
   #[inline]
   pub fn concat_clone<const N2: usize>(
     &self,
     other: &StaticVec<T, N2>,
   ) -> StaticVec<T, { N + N2 }>
-  where
-    T: Clone,
-  {
+  where T: Clone {
     let mut res = StaticVec::new();
     for i in 0..self.length {
       unsafe { res.push_unchecked(self.get_unchecked(i).clone()) };
@@ -1100,6 +1106,7 @@ impl<T, const N: usize> StaticVec<T, N> {
     self.length = 0;
     unsafe {
       for i in 0..old_length {
+        // This is fine because we intentionally set length to `0` ourselves just now.
         let val = self.mut_ptr_at_unchecked(i);
         if filter(&mut *val) {
           res.mut_ptr_at_unchecked(res.length).write(val.read());
@@ -1328,6 +1335,7 @@ impl<T, const N: usize> StaticVec<T, N> {
   ///   [1, 2, 3, 4],
   /// );
   /// ```
+  #[rustfmt::skip]
   #[inline]
   pub fn union<const N2: usize>(&self, other: &StaticVec<T, N2>) -> StaticVec<T, { N + N2 }>
   where T: Clone + PartialEq {
