@@ -1,11 +1,11 @@
 use crate::iterators::*;
-use crate::utils::partial_compare;
-use crate::utils::{make_const_slice, make_mut_slice, ptr_mut};
+use crate::utils::{make_const_slice, make_mut_slice, partial_compare, ptr_mut};
 use crate::StaticVec;
 use core::cmp::{Eq, Ord, Ordering, PartialEq};
 use core::fmt::{self, Debug, Formatter};
 use core::hash::{Hash, Hasher};
-use core::iter::FromIterator;
+#[doc(hidden)]
+pub use core::iter::FromIterator;
 use core::ops::{
   Deref, DerefMut, Index, IndexMut, Range, RangeFrom, RangeFull, RangeInclusive, RangeTo,
   RangeToInclusive,
@@ -33,79 +33,6 @@ use serde::{
   Deserialize, Deserializer, Serialize, Serializer,
 };
 
-/// A Helper trait for specialization-based implementations of [`Extend`](core::iter::Extend) and
-/// ['FromIterator`](core::iter::FromIterator).
-trait ExtendEx<T, I> {
-  fn extend_ex(&mut self, iter: I);
-  fn from_iter_ex(iter: I) -> Self;
-}
-
-impl<T, I: IntoIterator<Item = T>, const N: usize> ExtendEx<T, I> for StaticVec<T, N> {
-  impl_extend_ex!(val, val);
-  impl_from_iter_ex!(val, val);
-}
-
-impl<'a, T: 'a + Copy, I: IntoIterator<Item = &'a T>, const N: usize> ExtendEx<&'a T, I>
-  for StaticVec<T, N>
-{
-  impl_extend_ex!(val, (*val));
-  impl_from_iter_ex!(val, (*val));
-}
-
-impl<'a, T: 'a + Copy, const N: usize> ExtendEx<&'a T, StaticVecIterConst<'a, T, N>>
-  for StaticVec<T, N>
-{
-  #[inline(always)]
-  default fn extend_ex(&mut self, iter: StaticVecIterConst<'a, T, N>) {
-    self.extend_from_slice(iter.as_slice());
-  }
-
-  #[inline(always)]
-  default fn from_iter_ex(iter: StaticVecIterConst<'a, T, N>) -> Self {
-    Self::new_from_slice(iter.as_slice())
-  }
-}
-
-impl<'a, T: 'a + Copy, const N1: usize, const N2: usize>
-  ExtendEx<&'a T, StaticVecIterConst<'a, T, N2>> for StaticVec<T, N1>
-{
-  #[inline(always)]
-  default fn extend_ex(&mut self, iter: StaticVecIterConst<'a, T, N2>) {
-    self.extend_from_slice(iter.as_slice());
-  }
-
-  #[inline(always)]
-  default fn from_iter_ex(iter: StaticVecIterConst<'a, T, N2>) -> Self {
-    Self::new_from_slice(iter.as_slice())
-  }
-}
-
-impl<'a, T: 'a + Copy, const N: usize> ExtendEx<&'a T, core::slice::Iter<'a, T>>
-  for StaticVec<T, N>
-{
-  #[inline(always)]
-  fn extend_ex(&mut self, iter: core::slice::Iter<'a, T>) {
-    self.extend_from_slice(iter.as_slice());
-  }
-
-  #[inline(always)]
-  fn from_iter_ex(iter: core::slice::Iter<'a, T>) -> Self {
-    Self::new_from_slice(iter.as_slice())
-  }
-}
-
-impl<'a, T: 'a + Copy, const N: usize> ExtendEx<&'a T, &'a [T]> for StaticVec<T, N> {
-  #[inline(always)]
-  fn extend_ex(&mut self, iter: &'a [T]) {
-    self.extend_from_slice(iter);
-  }
-
-  #[inline(always)]
-  fn from_iter_ex(iter: &'a [T]) -> Self {
-    Self::new_from_slice(iter)
-  }
-}
-
 impl<T, const N: usize> AsMut<[T]> for StaticVec<T, N> {
   #[inline(always)]
   fn as_mut(&mut self) -> &mut [T] {
@@ -160,7 +87,8 @@ impl<T: Clone, const N: usize> Clone for StaticVec<T, N> {
 impl<T: Copy, const N: usize> Clone for StaticVec<T, N> {
   #[inline(always)]
   fn clone(&self) -> Self {
-    match self.length {
+    let length = self.length;
+    match length {
       // If `self` is empty, just return a new StaticVec.
       0 => Self::new(),
       _ => Self {
@@ -169,11 +97,11 @@ impl<T: Copy, const N: usize> Clone for StaticVec<T, N> {
           unsafe {
             self
               .as_ptr()
-              .copy_to_nonoverlapping(ptr_mut(&mut res), self.length);
+              .copy_to_nonoverlapping(ptr_mut(&mut res), length);
             res
           }
         },
-        length: self.length,
+        length,
       },
     }
   }
@@ -227,6 +155,100 @@ impl<T, const N: usize> Drop for StaticVec<T, N> {
 
 impl<T: Eq, const N: usize> Eq for StaticVec<T, N> {}
 
+/// A helper trait for specialization-based implementations of [`Extend`](core::iter::Extend) and
+/// ['FromIterator`](core::iter::FromIterator).
+trait ExtendEx<T, I> {
+  fn extend_ex(&mut self, iter: I);
+  fn from_iter_ex(iter: I) -> Self;
+}
+
+impl<T, I: IntoIterator<Item = T>, const N: usize> ExtendEx<T, I> for StaticVec<T, N> {
+  impl_extend_ex!(val, val);
+  impl_from_iter_ex!(val, val);
+}
+
+#[rustfmt::skip]
+impl<'a, T: 'a + Copy, I: IntoIterator<Item = &'a T>, const N: usize> ExtendEx<&'a T, I> for StaticVec<T, N> {
+  impl_extend_ex!(val, (*val));
+  impl_from_iter_ex!(val, (*val));
+}
+
+impl<'a, T: 'a + Copy, const N: usize> ExtendEx<&'a T, &StaticVec<T, N>> for StaticVec<T, N> {
+  #[inline(always)]
+  default fn extend_ex(&mut self, iter: &StaticVec<T, N>) {
+    self.extend_from_slice(iter);
+  }
+
+  #[inline(always)]
+  default fn from_iter_ex(iter: &StaticVec<T, N>) -> Self {
+    Self::new_from_slice(iter)
+  }
+}
+
+#[rustfmt::skip]
+impl<'a, T: 'a + Copy, const N1: usize, const N2: usize> ExtendEx<&'a T, &StaticVec<T, N2>> for StaticVec<T, N1> {
+  #[inline(always)]
+  default fn extend_ex(&mut self, iter: &StaticVec<T, N2>) {
+    self.extend_from_slice(iter);
+  }
+
+  #[inline(always)]
+  default fn from_iter_ex(iter: &StaticVec<T, N2>) -> Self {
+    Self::new_from_slice(iter)
+  }
+}
+
+#[rustfmt::skip]
+impl<'a, T: 'a + Copy, const N: usize> ExtendEx<&'a T, StaticVecIterConst<'a, T, N>> for StaticVec<T, N> {
+  #[inline(always)]
+  default fn extend_ex(&mut self, iter: StaticVecIterConst<'a, T, N>) {
+    self.extend_from_slice(iter.as_slice());
+  }
+
+  #[inline(always)]
+  default fn from_iter_ex(iter: StaticVecIterConst<'a, T, N>) -> Self {
+    Self::new_from_slice(iter.as_slice())
+  }
+}
+
+#[rustfmt::skip]
+impl<'a, T: 'a + Copy, const N1: usize, const N2: usize> ExtendEx<&'a T, StaticVecIterConst<'a, T, N2>> for StaticVec<T, N1> {
+  #[inline(always)]
+  default fn extend_ex(&mut self, iter: StaticVecIterConst<'a, T, N2>) {
+    self.extend_from_slice(iter.as_slice());
+  }
+
+  #[inline(always)]
+  default fn from_iter_ex(iter: StaticVecIterConst<'a, T, N2>) -> Self {
+    Self::new_from_slice(iter.as_slice())
+  }
+}
+
+#[rustfmt::skip]
+impl<'a, T: 'a + Copy, const N: usize> ExtendEx<&'a T, core::slice::Iter<'a, T>> for StaticVec<T, N> {
+  #[inline(always)]
+  fn extend_ex(&mut self, iter: core::slice::Iter<'a, T>) {
+    self.extend_from_slice(iter.as_slice());
+  }
+
+  #[inline(always)]
+  fn from_iter_ex(iter: core::slice::Iter<'a, T>) -> Self {
+    Self::new_from_slice(iter.as_slice())
+  }
+}
+
+impl<'a, T: 'a + Copy, const N: usize> ExtendEx<&'a T, &'a [T]> for StaticVec<T, N> {
+  #[inline(always)]
+  fn extend_ex(&mut self, iter: &'a [T]) {
+    self.extend_from_slice(iter);
+  }
+
+  #[inline(always)]
+  fn from_iter_ex(iter: &'a [T]) -> Self {
+    Self::new_from_slice(iter)
+  }
+}
+
 impl<T, const N: usize> Extend<T> for StaticVec<T, N> {
   #[inline(always)]
   fn extend<I: IntoIterator<Item = T>>(&mut self, iter: I) {
@@ -634,7 +656,8 @@ impl<const N: usize> Read for StaticVec<u8, N> {
 
   #[inline]
   fn read(&mut self, buf: &mut [u8]) -> io::Result<usize> {
-    let read_length = self.length.min(buf.len());
+    let current_length = self.length;
+    let read_length = current_length.min(buf.len());
     // Safety:  read_length <= buf.length and self.length. Rust borrowing
     // rules mean that buf is guaranteed not to overlap with self.
     unsafe {
@@ -642,14 +665,14 @@ impl<const N: usize> Read for StaticVec<u8, N> {
         .as_mut_ptr()
         .copy_from_nonoverlapping(self.as_ptr(), read_length);
     }
-    if read_length < self.length {
+    if read_length < current_length {
       // TODO: find out if the optimizer elides the bounds check here. It
       // should be able to, since the only non-const value is read_length,
       // which is known to be <= self.length
       self.as_mut_slice().copy_within(read_length.., 0);
     }
     // Safety: 0 <= read_length <= self.length
-    self.length -= read_length;
+    unsafe { self.set_len(current_length - read_length) };
     Ok(read_length)
   }
 
@@ -763,17 +786,16 @@ impl<const N: usize> Write for StaticVec<u8, N> {
 }
 
 #[cfg(feature = "serde_support")]
+#[rustfmt::skip]
 impl<'de, T, const N: usize> Deserialize<'de> for StaticVec<T, N>
-where T: Deserialize<'de>
-{
+where T: Deserialize<'de> {
   #[inline]
   fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
   where D: Deserializer<'de> {
     struct StaticVecVisitor<'de, T, const N: usize>(PhantomData<(&'de (), T)>);
 
     impl<'de, T, const N: usize> Visitor<'de> for StaticVecVisitor<'de, T, N>
-    where T: Deserialize<'de>
-    {
+    where T: Deserialize<'de> {
       type Value = StaticVec<T, N>;
 
       #[inline(always)]
@@ -802,9 +824,9 @@ where T: Deserialize<'de>
 }
 
 #[cfg(feature = "serde_support")]
+#[rustfmt::skip]
 impl<T, const N: usize> Serialize for StaticVec<T, N>
-where T: Serialize
-{
+where T: Serialize {
   #[inline(always)]
   fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
   where S: Serializer {
