@@ -509,6 +509,29 @@ fn from() {
   );
 }
 
+#[test]
+fn from_iter() {
+  assert_eq!(
+    StaticVec::<u8, 12>::from_iter(&[1, 2, 3, 4, 5, 6]),
+    [1, 2, 3, 4, 5, 6]
+  );
+  assert_eq!(
+    StaticVec::<u8, 12>::from_iter([1, 2, 3, 4, 5, 6].iter()),
+    [1, 2, 3, 4, 5, 6]
+  );
+  assert_eq!(
+    StaticVec::<u8, 12>::from_iter(staticvec![1, 2, 3, 4, 5, 6].iter()),
+    [1, 2, 3, 4, 5, 6]
+  );
+  assert_eq!(StaticVec::<u8, 0>::from_iter(&[1, 2, 3, 4, 5, 6]), []);
+  assert_eq!(
+    StaticVec::<Box<Struct>, 2>::from_iter(
+      staticvec![Box::new(Struct { s: "A" }), Box::new(Struct { s: "B" })].into_iter()
+    ),
+    [Box::new(Struct { s: "A" }), Box::new(Struct { s: "B" })]
+  );
+}
+
 #[cfg(feature = "std")]
 #[test]
 fn from_vec() {
@@ -576,7 +599,7 @@ fn insert() {
   assert_eq!(vec, [1, 4, 2, 3, 5]);
 }
 
-// The next few tests for `insert_many` are adapted from the SmallVec testsuite.
+// The next couple of tests for `insert_many` are adapted from the SmallVec testsuite.
 
 #[test]
 fn insert_many() {
